@@ -1,29 +1,35 @@
-package Devel::Command::DBSub::DB_5_10;
+package Devel::Command::DBSub::DB_5_8_6;
 
 sub import {
-  if (my($sub_version) = 
-        # 5.9.5's debugger is based on the 5.10 release.
-        ($] =~ /^5.010(.*)/ or $] =~ /^5.009005/)
-     ) {
-      return \&DB::alt_510_DB;
-    }
-    else {
-      # Not 5.10 or 5.9.5.
-      return undef;
+  # Includes 5.8.6, 5.8.7 and 5.8.8.
+  # Also includes 5.9.2, 5.9.3 and 5.9.4.
+  if( $] gt "5.008005" or 
+      ( $] gt "5.009001" and
+        $] lt "5.009005"
+      ) 
+    ) {
+    return \&DB::alt_586_DB;
+  }
+  else {
+    return;
   }
 }
 
 {
 no strict;
 no warnings;
+package DB;
 
-sub alt_510_DB {
+sub alt_586_DB {
 
     # lock the debugger and get the thread id for the prompt
 	lock($DBGR);
 	my $tid;
 	if ($ENV{PERL5DB_THREADED}) {
-		$tid = eval { "[".threads->tid."]" };
+		$tid = eval { "[".threads->self->tid."]" };
+	}
+	else {
+	        $tid = "";
 	}
 
     # Check for whether we should be running continuously or not.
@@ -174,7 +180,7 @@ EOP
             print_help(<<EOP);
 Debugged program terminated.  Use B<q> to quit or B<R> to restart,
   use B<o> I<inhibit_exit> to avoid stopping after program termination,
-  B<h q>, B<h R> or B<h o> to get additional info.  
+  B<h q>, B<h R> or B<h O> to get additional info.  
 EOP
 
             # Set the DB::eval context appropriately.
@@ -300,7 +306,7 @@ EOP
           )
         {
 
-			share($cmd);
+			defined \&share and share($cmd);
             # ... try to execute the input as debugger commands.
 
             # Don't stop running.
@@ -351,16 +357,16 @@ EOP
                     }
                 } ## end if ($alias{$i})
 
-                ### Extended commands
+### Extended commands
 
-                ### Define your extended commands in C<%commands> at the top of the file.
-                ### This section runs them.
+### Define your extended commands in C<%commands> at the top of the file.
+### This section runs them.
 
-                foreach my $do (keys %DB::commands) {
+               foreach my $do (keys %DB::commands) {
                  next unless $cmd =~ /^$do\s*/;
                  $commands{$do}->($cmd) and next CMD;
-                 #  ? next CMD : last CMD;
-                }
+		 #  ? next CMD : last CMD;
+               }
 
                 $cmd =~ /^q$/ && do {
                     $fall_off_end = 1;
@@ -419,7 +425,7 @@ EOP
                     @vars     = split( ' ', $2 );
 
                     # If main::dumpvar isn't here, get it.
-                    do 'dumpvar.pl' || die $@ unless defined &main::dumpvar;
+                    do 'dumpvar.pl' unless defined &main::dumpvar;
                     if ( defined &main::dumpvar ) {
 
                         # We got it. Turn off subroutine entry/exit messages
@@ -567,7 +573,7 @@ EOP
                       and next CMD;
 
                     # Load up dumpvar if we don't have it. If we can, that is.
-                    do 'dumpvar.pl' || die $@ unless defined &main::dumpvar;
+                    do 'dumpvar.pl' unless defined &main::dumpvar;
                     defined &main::dumpvar
                       or print $OUT "dumpvar.pl not available.\n"
                       and next CMD;
@@ -620,7 +626,6 @@ EOP
                     last CMD;
                 };
 
-
                 # c - start continuous execution.
                 $cmd =~ /^c\b\s*([\w:]*)\s*$/ && do {
 
@@ -694,7 +699,7 @@ EOP
                     # sure that the line specified really is breakable.
                     #
                     # On the other hand, if there was a subname supplied, the
-                    # preceding block has moved us to the proper file and
+                    # preceeding block has moved us to the proper file and
                     # location within that file, and then scanned forward
                     # looking for the next executable line. We have to make
                     # sure that one was found.
@@ -1215,10 +1220,8 @@ EOP
                 $onetimedumpDepth = undef;
             }
             elsif ( $term_pid == $$ ) {
-		eval {		# May run under miniperl, when not available...
-                    STDOUT->flush();
-                    STDERR->flush();
-		};
+                STDOUT->flush();
+                STDERR->flush();
 
                 # XXX If this is the master pid, print a newline.
                 print $OUT "\n";
@@ -1305,7 +1308,7 @@ __END__
 
 =head1 NAME
 
-Devel::Command::DBSub::DB_5_10 - Devel::Command debugger patch for 5.10
+Devel::Command::DBSub::DB_5_8_6 - Devel::Command debugger patch for 5.8.6 and up
 
 =head1 SYNOPSIS
 
@@ -1314,12 +1317,12 @@ Devel::Command::DBSub::DB_5_10 - Devel::Command debugger patch for 5.10
 
 =head1 DESCRIPTION
 
-C<Devel::Command::DBSub::DB_5_10> loads a patched version of the debugger's
-C<DB()> routine that will work with Perl 5.10.
+C<Devel::Command::DBSub::DB_5_8_6> loads a patched version of the debugger's
+C<DB()> routine that will work with Perl 5.8.6 and up.
 
-=head2 alt_510_DB
+=head2 alt_586_DB
 
-This subroutine is essentially a copy of the 5.10 DB::DB function, with the code
+This subroutine is essentially a copy of the 5.8.6 DB::DB function, with the code
 necessary to pick up custom functions patched in.
 
 =head1 NOTE
@@ -1346,4 +1349,6 @@ This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.6 or,
 at your option, any later version of Perl 5 you may have available.
 
-=cut
\ No newline at end of file
+
+=cut
+
